@@ -39,7 +39,6 @@ sub identify {
     $count = 1 if not $count;
     for ( 1..$count ) {
         push @cpu, {
-            architecture  => ($CPU{id} =~ m{ \A (.+?) \s? Family }xmsi),
             data_width    => undef,
             speed         => undef,
             bus_speed     => undef,
@@ -128,9 +127,6 @@ sub _INTEL {
             9     => 'Mobile Pentium III',
             10    => 'Pentium III (0.18 m)',
             11    => 'Pentium III (0.13 m)',
-
-            13    => 'Celeron M', # ???
-            15    => 'Core 2 Duo (Merom)', # ???
     },
     7  => {
             0     => 'Itanium (IA-64)',
@@ -278,16 +274,6 @@ These C<%ENV> keys are recognised by this module:
    PROCESSOR_REVISION
    PROCESSOR_LEVEL
 
-=head1 METHODS
-
-=head2 identify
-
-See identify in L<Sys::Info::Device::CPU>.
-
-=head2 load
-
-See load in L<Sys::Info::Device::CPU>.
-
 =head1 SEE ALSO
 
 L<Sys::Info>,
